@@ -18,6 +18,7 @@ from typing import Dict, List, Sequence, Union
 from .literals import (
     AlarmTypeType,
     AnomalyDetectorStateValueType,
+    AnomalyDetectorTypeType,
     ComparisonOperatorType,
     HistoryItemTypeType,
     MetricStreamOutputFormatType,
@@ -102,6 +103,7 @@ __all__ = (
     "MetricDataQueryTypeDef",
     "MetricDataResultTypeDef",
     "MetricDatumTypeDef",
+    "MetricMathAnomalyDetectorTypeDef",
     "MetricStatTypeDef",
     "MetricStreamEntryTypeDef",
     "MetricStreamFilterTypeDef",
@@ -124,6 +126,7 @@ __all__ = (
     "ServiceResourceMetricRequestTypeDef",
     "SetAlarmStateInputAlarmTypeDef",
     "SetAlarmStateInputRequestTypeDef",
+    "SingleMetricAnomalyDetectorTypeDef",
     "StartMetricStreamsInputRequestTypeDef",
     "StatisticSetTypeDef",
     "StopMetricStreamsInputRequestTypeDef",
@@ -164,6 +167,8 @@ AnomalyDetectorTypeDef = TypedDict(
         "Stat": str,
         "Configuration": "AnomalyDetectorConfigurationTypeDef",
         "StateValue": AnomalyDetectorStateValueType,
+        "SingleMetricAnomalyDetector": "SingleMetricAnomalyDetectorTypeDef",
+        "MetricMathAnomalyDetector": "MetricMathAnomalyDetectorTypeDef",
     },
     total=False,
 )
@@ -230,30 +235,19 @@ DeleteAlarmsInputRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteAnomalyDetectorInputRequestTypeDef = TypedDict(
-    "_RequiredDeleteAnomalyDetectorInputRequestTypeDef",
+DeleteAnomalyDetectorInputRequestTypeDef = TypedDict(
+    "DeleteAnomalyDetectorInputRequestTypeDef",
     {
         "Namespace": str,
         "MetricName": str,
-        "Stat": str,
-    },
-)
-_OptionalDeleteAnomalyDetectorInputRequestTypeDef = TypedDict(
-    "_OptionalDeleteAnomalyDetectorInputRequestTypeDef",
-    {
         "Dimensions": Sequence["DimensionTypeDef"],
+        "Stat": str,
+        "SingleMetricAnomalyDetector": "SingleMetricAnomalyDetectorTypeDef",
+        "MetricMathAnomalyDetector": "MetricMathAnomalyDetectorTypeDef",
     },
     total=False,
 )
 
-
-class DeleteAnomalyDetectorInputRequestTypeDef(
-    _RequiredDeleteAnomalyDetectorInputRequestTypeDef,
-    _OptionalDeleteAnomalyDetectorInputRequestTypeDef,
-):
-    pass
-
-
 DeleteDashboardsInputRequestTypeDef = TypedDict(
     "DeleteDashboardsInputRequestTypeDef",
     {
@@ -390,6 +384,7 @@ DescribeAnomalyDetectorsInputRequestTypeDef = TypedDict(
         "Namespace": str,
         "MetricName": str,
         "Dimensions": Sequence["DimensionTypeDef"],
+        "AnomalyDetectorTypes": Sequence[AnomalyDetectorTypeType],
     },
     total=False,
 )
@@ -942,6 +937,14 @@ class MetricDatumTypeDef(_RequiredMetricDatumTypeDef, _OptionalMetricDatumTypeDe
     pass
 
 
+MetricMathAnomalyDetectorTypeDef = TypedDict(
+    "MetricMathAnomalyDetectorTypeDef",
+    {
+        "MetricDataQueries": Sequence["MetricDataQueryTypeDef"],
+    },
+    total=False,
+)
+
 _RequiredMetricStatTypeDef = TypedDict(
     "_RequiredMetricStatTypeDef",
     {
@@ -990,7 +993,7 @@ MetricTypeDef = TypedDict(
     {
         "Namespace": str,
         "MetricName": str,
-        "Dimensions": List["DimensionTypeDef"],
+        "Dimensions": Sequence["DimensionTypeDef"],
     },
     total=False,
 )
@@ -1016,30 +1019,20 @@ PartialFailureTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredPutAnomalyDetectorInputRequestTypeDef = TypedDict(
-    "_RequiredPutAnomalyDetectorInputRequestTypeDef",
+PutAnomalyDetectorInputRequestTypeDef = TypedDict(
+    "PutAnomalyDetectorInputRequestTypeDef",
     {
         "Namespace": str,
         "MetricName": str,
-        "Stat": str,
-    },
-)
-_OptionalPutAnomalyDetectorInputRequestTypeDef = TypedDict(
-    "_OptionalPutAnomalyDetectorInputRequestTypeDef",
-    {
         "Dimensions": Sequence["DimensionTypeDef"],
+        "Stat": str,
         "Configuration": "AnomalyDetectorConfigurationTypeDef",
+        "SingleMetricAnomalyDetector": "SingleMetricAnomalyDetectorTypeDef",
+        "MetricMathAnomalyDetector": "MetricMathAnomalyDetectorTypeDef",
     },
     total=False,
 )
 
-
-class PutAnomalyDetectorInputRequestTypeDef(
-    _RequiredPutAnomalyDetectorInputRequestTypeDef, _OptionalPutAnomalyDetectorInputRequestTypeDef
-):
-    pass
-
-
 _RequiredPutCompositeAlarmInputRequestTypeDef = TypedDict(
     "_RequiredPutCompositeAlarmInputRequestTypeDef",
     {
@@ -1307,6 +1300,17 @@ class SetAlarmStateInputRequestTypeDef(
     pass
 
 
+SingleMetricAnomalyDetectorTypeDef = TypedDict(
+    "SingleMetricAnomalyDetectorTypeDef",
+    {
+        "Namespace": str,
+        "MetricName": str,
+        "Dimensions": Sequence["DimensionTypeDef"],
+        "Stat": str,
+    },
+    total=False,
+)
+
 StartMetricStreamsInputRequestTypeDef = TypedDict(
     "StartMetricStreamsInputRequestTypeDef",
     {
